@@ -170,6 +170,8 @@ class Renderer(JsRenderer, JsCacheRenderer):
         if v.select_rows: result['select_rows'] = v.select_rows
         if v.submit_form_data: result['submit_form_data'] = True
         if v.button_text: result['button_text'] = v.button_text
+        if v.show_in_side_toolbar: result['show_in_side_toolbar'] = True
+        if v.never_collapse: result['never_collapse'] = True
 
         icon = self.get_action_icon(v)
         if icon: result['icon'] = icon
@@ -616,7 +618,6 @@ class Renderer(JsRenderer, JsCacheRenderer):
                                   "hide_navigator "
                                   "use_detail_params_value "
                                   "react_responsive "
-                                  # "display_mode "
                                   "max_render_depth "
                                   "simple_slavegrid_header "
                                   "paginator_template "
