@@ -152,13 +152,22 @@ class ApiList(View):
                 constants.URL_PARAM_DISPLAY_MODE, constants.DISPLAY_MODE_TABLE)
 
             if display_mode == constants.DISPLAY_MODE_STORY:
-                story = ""
+                html_text = ""
                 rows = []
                 for obj in ar.sliced_data_iterator:
-                    story += obj.as_story_item(ar)
+                    html_text += obj.as_story_item(ar)
+                    rows.append({'id': obj.pk})
+            elif display_mode == constants.DISPLAY_MODE_LIST:
+                html_text = ""
+                rows = []
+                for obj in ar.sliced_data_iterator:
+                    url = ar.renderer.obj2url(ar, obj)
+                    # url = url.replace('"', r'\"')
+                    html_text += """<a href="{}"><p>{}</p></a>""".format(
+                        url, ar.row_as_paragraph(obj))
                     rows.append({'id': obj.pk})
             else:
-                story = None
+                html_text = None
                 def serialize(ar, row):
                     """Use display_mode to determine which serilisation store method and fields to use"""
                     if display_mode == constants.DISPLAY_MODE_TABLE:
@@ -169,8 +178,6 @@ class ApiList(View):
                     else:
                         if display_mode == constants.DISPLAY_MODE_CARDS:
                             fields = rh.store.card_fields
-                        elif display_mode == constants.DISPLAY_MODE_LIST:
-                            fields = rh.store.item_fields
                         else:
                             fields = rh.store.detail_fields
                         return rh.store.row2dict(ar,
@@ -189,7 +196,7 @@ class ApiList(View):
             # assert len(rows) <= ar.limit
             kw = dict(count=total_count,
                       rows=rows,
-                      story=story,
+                      html_text=html_text,
                       success=True,
                       no_data_text=ar.no_data_text,
                       title=ar.get_title())
@@ -276,7 +283,7 @@ class DelayedValue(View):
         if de is None:
             v = "{} has no data element {}".format(rpt, field)
         else:
-            ar = rpt.request(request=request)
+            ar = rpt.request(request=request, renderer=settings.SITE.plugins.react.renderer)
             if pk == '-99998':
                 row = None
             else:
@@ -661,9 +668,7 @@ class UserSettings(View):
             if (not settings.SITE.build_js_cache_on_startup
                 and not settings.SITE.never_build_site_cache):
                 settings.SITE.plugins.react.renderer.build_js_cache(False)
-                separate_site_cache_root = False
-            else:
-                separate_site_cache_root = True
+
             user_settings = dict(
                 user_type=u.user_type,
                 dashboard_items=len(u.get_preferences().dashboard_items),
@@ -683,8 +688,6 @@ class UserSettings(View):
                 my_setting_text=settings.SITE.is_installed('users') and settings.SITE.plugins.users.my_setting_text or _("My settings"),
                 user_id=u.pk,
             )
-            if separate_site_cache_root:
-                user_settings['separate_site_cache_root'] = True
 
             if su_name:
                 user_settings["user_id"] = user_settings["su_id"] = su.id
